@@ -5,15 +5,11 @@ class CONFIG:
     """General"""
     USE_CUDA = False
     if torch.cuda.device_count() > 0:
-        try:
-            torch.ones(1).cuda().__repr__()
-            # pytorch wheels support compute capability >= 3.7
-            major, minor = torch.cuda.get_device_capability()
-            if major + minor/10 >= 3.7:
-                USE_CUDA = True
-            else:
-                USE_CUDA = False
-        except Exception as e:
+        # pytorch wheels support compute capability >= 3.7
+        major, minor = torch.cuda.get_device_capability()
+        if major + minor/10 >= 3.7:
+            USE_CUDA = True
+        else:
             USE_CUDA = False
     USE_DEVICE = None
 
