@@ -4,7 +4,6 @@ from lightwood.encoders.image.img_2_vec import Img2VecEncoder
 from lightwood.encoders.image.nn import NnAutoEncoder
 from lightwood.encoders.numeric.numeric import NumericEncoder
 from lightwood.encoders.numeric.ts_numeric import TsNumericEncoder
-from lightwood.encoders.text.distilbert import DistilBertEncoder
 from lightwood.encoders.text.short import ShortTextEncoder
 from lightwood.encoders.text.vocab import VocabularyEncoder
 from lightwood.encoders.text.rnn import RnnEncoder as TextRnnEncoder
@@ -12,8 +11,8 @@ from lightwood.encoders.categorical.onehot import OneHotEncoder
 from lightwood.encoders.categorical.autoencoder import CategoricalAutoEncoder
 from lightwood.encoders.time_series.rnn import TimeSeriesEncoder as TsRnnEncoder
 from lightwood.encoders.time_series.plain import TimeSeriesPlainEncoder
-# from lightwood.encoders.audio.amplitude_ts import AmplitudeTsEncoder
 from lightwood.encoders.categorical.multihot import MultiHotEncoder
+from lightwood.encoders.text.pretrained import PretrainedLang
 
 
 class DateTime:
@@ -31,10 +30,10 @@ class Numeric:
 
 
 class Text:
-    DistilBertEncoder = DistilBertEncoder
     ShortTextEncoder = ShortTextEncoder
     TextRnnEncoder = TextRnnEncoder
     VocabularyEncoder = VocabularyEncoder
+    PretrainedLang = PretrainedLang
 
 class Categorical:
     OneHotEncoder = OneHotEncoder
