@@ -5,7 +5,7 @@ import requests
 import numpy as np
 import torch
 
-from lightwood.encoders.time_series.rnn import RnnEncoder
+from lightwood.encoders.time_series.rnn import TimeSeriesEncoder
 from lightwood.encoders.encoder_base import BaseEncoder
 from lightwood.logger import log
 
@@ -14,7 +14,7 @@ class AmplitudeTsEncoder(BaseEncoder):
 
     def __init__(self, is_target=False):
         super().__init__(is_target)
-        self._ts_encoder = RnnEncoder()
+        self._ts_encoder = TimeSeriesEncoder()
         self._max_samples = 2000
 
     def encode(self, column_data):
